@@ -9,26 +9,10 @@ ipmisc::`%>%`
 #' @importFrom ipmisc "%<>%"
 ipmisc::`%<>%`
 
-#' @export
-#' @importFrom ipmisc "%$%"
-ipmisc::`%$%`
-
 #' @export
 #' @importFrom ipmisc "%<-%"
 ipmisc::`%<-%`
 
-#' @export
-#' @importFrom rlang "%||%"
-rlang::`%||%`
-
-#' @export
-#' @importFrom rlang "%|%"
-rlang::`%|%`
-
-#' @export
-#' @importFrom rlang ":="
-rlang::`:=`
-
 #' @export
 #' @importFrom ipmisc tibble
 ipmisc::tibble
