@@ -78,11 +78,6 @@ testthat::test_that(
       )
     )
 
-    testthat::expect_identical(
-      df1$significance,
-      c("**", "ns", "***", "ns", "**", "***")
-    )
-
     testthat::expect_equal(
       df2$statistic,
       c(
@@ -108,11 +103,6 @@ testthat::test_that(
       )
     )
 
-    testthat::expect_identical(
-      df2$significance,
-      c("***", "*", "***", "*", "**", "***")
-    )
-
     testthat::expect_equal(
       df3$estimate,
       c(
@@ -138,11 +128,6 @@ testthat::test_that(
       )
     )
 
-    testthat::expect_identical(
-      df3$significance,
-      c("**", "ns", "***", "ns", "*", "***")
-    )
-
     testthat::expect_identical(
       df4$label,
       c(
@@ -156,10 +141,10 @@ testthat::test_that(
     )
 
     # checking if it is a tibble
-    testthat::expect_is(df1, "tbl_df")
-    testthat::expect_is(df2, "tbl_df")
-    testthat::expect_is(df3, "tbl_df")
-    testthat::expect_is(df4, "tbl_df")
+    testthat::expect_s3_class(df1, "tbl_df")
+    testthat::expect_s3_class(df2, "tbl_df")
+    testthat::expect_s3_class(df3, "tbl_df")
+    testthat::expect_s3_class(df4, "tbl_df")
 
     # columns should be same no matter the test
     testthat::expect_identical(df1$group1, df2$group1)
@@ -256,11 +241,6 @@ testthat::test_that(
       )
     )
 
-    testthat::expect_identical(
-      df1$significance,
-      c("ns", "*", "***")
-    )
-
     testthat::expect_equal(
       df2$statistic,
       c(1.04673405118638, 3.66356917915232, 2.61683512796594),
@@ -276,11 +256,6 @@ testthat::test_that(
       )
     )
 
-    testthat::expect_identical(
-      df2$significance,
-      c("ns", "***", "*")
-    )
-
     testthat::expect_equal(
       df3$estimate,
       c(0.0166666666666668, 0.1, 0.0777777777777778),
@@ -296,11 +271,6 @@ testthat::test_that(
       )
     )
 
-    testthat::expect_identical(
-      df3$significance,
-      c("ns", "*", "**")
-    )
-
     testthat::expect_identical(
       df4$label,
       c(
